#' Calculation of the F1 Score
#'
#' Calculates the value of F1 Score
#'
#' @param true.values correct labels of data (1-2)
#' @param predicted.values predicted values of labes, returned by classifier
#' @param positive An optional character string for the factor level that corresponds to a "positive" result
#' 
#' @return the correspondent f1score value
#'
#' @examples
#' data(cars)
#' logreg <- glm(formula = vs ~ hp + wt,
#' family = binomial(link = "logit"), data = mtcars)
#' pred <- ifelse(logreg$fitted.values < 0.5, 1, 2)
#' f1score(true.values = mtcars$vs, predicted.values = pred, positive = 1)
#' f1score(true.values = mtcars$vs, predicted.values = pred, positive = 2)
#'
#' @author Aleksander Denisiuk, \email{denisiuk@@matman.uwm.edu.pl}
#' @references \url{https://en.wikipedia.org/wiki/F-score}
#' @seealso \code{\link[MLmetrics]{F1_Score}}
#' @keywords f1score
#'
#' @export

f1score <- function( true.values, predicted.values, positive=1){
      true_positive <- sum( true.values==positive & predicted.values==positive )
      false_positive <- sum( true.values!=positive & predicted.values==positive )
      false_negative <- sum( true.values==positive & predicted.values!=positive )
      precision = 0
      if (true_positive>0){
        precision = true_positive/(true_positive + false_positive)
      }
      recall = 0
      if( true_positive>0 ){
        recall = true_positive/(true_positive + false_negative)
      }
      f1 = 0
      if( precision+recall>0 ){
        f1 =  2.0*precision*recall/(precision+recall);
      }
      f1*100
}
